@@ -1,10 +1,5 @@
 package App::GenPericmdCompleterScript;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-04-30'; # DATE
-our $DIST = 'App-GenPericmdCompleterScript'; # DIST
-our $VERSION = '0.122'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -13,6 +8,12 @@ use Log::ger;
 use Data::Dmp;
 
 use Exporter qw(import);
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-21'; # DATE
+our $DIST = 'App-GenPericmdCompleterScript'; # DIST
+our $VERSION = '0.123'; # VERSION
+
 our @EXPORT_OK = qw(gen_pericmd_completer_script);
 
 our %SPEC;
@@ -267,8 +268,6 @@ sub gen_pericmd_completer_script {
                 "# NO_PERINCI_CMDLINE_SCRIPT\n",
                 "# PERINCI_CMDLINE_COMPLETER_SCRIPT: ", dmp(\%args), "\n",
                 "# FRAGMENT id=shcompgen-hint completer=1 for=$args{program_name}\n",
-                "# DATE\n",
-                "# VERSION\n",
                 "# PODNAME: _$args{program_name}\n",
                 "# ABSTRACT: Completer script for $args{program_name}\n",
                 "\n",
@@ -282,6 +281,11 @@ sub gen_pericmd_completer_script {
             "use warnings;\n",
             "\n",
 
+            "# AUTHORITY\n",
+            "# DATE\n",
+            "# DIST\n",
+            "# VERSION\n",
+
             'die "Please run this script under shell completion\n" unless $ENV{COMP_LINE} || $ENV{COMMAND_LINE};', "\n\n",
 
             ($args{load_module} ? (
@@ -376,7 +380,7 @@ sub gen_pericmd_completer_script {
             '            }', "\n",
             '', "\n",
             '            # otherwise let periscomp do its thing', "\n",
-            '            return undef;', "\n",
+            '            return undef; ## no critic: Subroutines::ProhibitExplicitReturnUndef', "\n",
             '        },', "\n",
             '    );', "\n",
             "}\n\n",
@@ -408,6 +412,7 @@ sub gen_pericmd_completer_script {
             overwrite      => 1,
             trace_method   => 'none',
             pack_method    => 'datapack',
+            code_after_shebang => "## no critic: TestingAndDebugging::RequireUseStrict\n", # currently datapack code does not use strict
         );
         if ($args{strip}) {
             $depakargs{stripper} = 1;
@@ -466,7 +471,7 @@ App::GenPericmdCompleterScript - Generate Perinci::CmdLine completer script
 
 =head1 VERSION
 
-This document describes version 0.122 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2020-04-30.
+This document describes version 0.123 of App::GenPericmdCompleterScript (from Perl distribution App-GenPericmdCompleterScript), released on 2021-10-21.
 
 =head1 FUNCTIONS
 
@@ -475,7 +480,7 @@ This document describes version 0.122 of App::GenPericmdCompleterScript (from Pe
 
 Usage:
 
- gen_pericmd_completer_script(%args) -> [status, msg, payload, meta]
+ gen_pericmd_completer_script(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Generate Perinci::CmdLine completer script.
 
@@ -573,12 +578,12 @@ URL to function (or package, if you have subcommands).
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -590,6 +595,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-GenPer
 
 Source repository is at L<https://github.com/perlancar/perl-App-GenPericmdCompleterScript>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016, 2015 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-GenPericmdCompleterScript>
@@ -598,15 +631,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2018, 2017, 2016, 2015 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
